@@ -1,3 +1,4 @@
+from zipfile import ZipFile
 from nonebot.log import logger
 import requests
 import os
@@ -28,4 +29,18 @@ def mes_list(mes,name_list:list):
     for i in name_list:
         n += 1
         mes += "\n" + str(n) + "、" + i
-    return mes
\ No newline at end of file
+    return mes
+
+def support_gbk(zip_file: ZipFile):
+    '''
+    中文恢复
+    '''
+    name_to_info = zip_file.NameToInfo
+    # copy map first
+    for name, info in name_to_info.copy().items():
+        real_name = name.encode('cp437').decode('gbk')
+        if real_name != name:
+            info.filename = real_name
+            del name_to_info[name]
+            name_to_info[real_name] = info
+    return zip_file
\ No newline at end of file
